.. tixte documentation master file, created by
   sphinx-quickstart on Wed Apr 27 14:58:07 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to py-presencedb.py's documentation!
============================================

py-presencedb is a modern, easy to use, and powerful tool for using the presencedb api
View Documentation
------------------

View the documentation for the library to learn about the features and
view the attributes and methods of tixte.py objects.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
